{{
        RIC_Thermostat.spin
        Thermostat code for controlling a propeller chip with:
                2x 7 Segment LEDs for displaying temperature data
                1x DS1620 for temperature control
                1x XBee module for wireless communications

}}

CON
  _clkmode = xtal1 + pll16x        'Sets the clock speed to 80 MHz using a times 16 multiplier
  _xinfreq = 5_000_000             'Crystal speed: 5 MHz

  'PIN constants for the DS1620
  PIN_DQ                        = 16
  PIN_CLK                       = 17
  PIN_RST                       = 18

  'PIN constants for the 7 Segment LEDs
  PIN_SPIL_CLOCK                = 10
  PIN_SPIL_STORE                = 11
  PIN_SPIL_DATA                 = 12
  PIN_SPIR_CLOCK                = 13
  PIN_SPIR_STORE                = 14
  PIN_SPIR_DATA                 = 15

  'PIN constants for the XBee module
  PIN_ENDPT_TX                  = 20
  PIN_ENDPT_RX                  = 21
   

OBJ

  'Left 7 Segment LED Object
  objLeftDisplay                : "RIC_7SegmentLED"
  objRightDisplay               : "RIC_7SegmentLED"
  objThermostat                 : "RIC_DS1620"
  objXBeeEndPt                  : "RIC_XBee"
  objTime                       : "Timing"
  objNumbers                    : "Numbers"                                                


VAR

  long lTempTens, lTempOnes 'Temp var for testing
  long lTemperature


PUB Main

  'Init the displays
  objLeftDisplay.Initialize (PIN_SPIL_DATA, PIN_SPIL_CLOCK, PIN_SPIL_STORE)
  objRightDisplay.Initialize (PIN_SPIR_DATA, PIN_SPIR_CLOCK, PIN_SPIR_STORE)

  'Init the XBee end point
  objXBeeEndPt.Initialize (PIN_ENDPT_RX, PIN_ENDPT_TX, 0, 9600)

  'Init the DS1620
  objThermostat.Initialize (PIN_DQ, PIN_CLK, PIN_RST)
  objThermostat.StartTemperatureConversion

  Repeat
    lTemperature := objThermostat.GetTemperatureF
    lTempTens := (lTemperature - (lTemperature // 10)) / 10
    lTempOnes := lTemperature - (lTempTens * 10)
    objLeftDisplay.SetValue (lTempTens)
    objRightDisplay.SetValue (lTempOnes)

    objXBeeEndPt.TX_String (objNumbers.ToStr (lTemperature, objNumbers#DEC))
    
    objTime.pause1ms (4000)
      